@@ -10,7 +10,7 @@ class FileWatcher:
         self.changer = changer
         self.observer = Observer()
 
-    def start_watching(self):
+    def start(self):
         """
         변경 사항을 감시하기 위해 루트 디렉토리를 감시하고 circleblock_cli.py 파일을 생성/업데이트합니다.
         """
@@ -19,10 +19,10 @@ class FileWatcher:
 
         self.observer.schedule(self.changer, self.project_root, recursive=True)
         self.observer.start()
-        signal.signal(signal.SIGINT, lambda *args, **kwargs: self.stop_watching())
+        signal.signal(signal.SIGINT, lambda *args, **kwargs: self.stop())
         signal.pause()
 
-    def stop_watching(self):
+    def stop(self):
         """
         변경 사항을 감지하는 루트 디렉토리의 감시를 중지합니다.
         """
